// Copyright 2015 The Go Authors. All rights reserved.
// Use of this source code is governed by a BSD-style
// license that can be found in the LICENSE file.

package arm64

// This order should be strictly consistent to that in a.out.go
var cnames7 = []string{
	"NONE",
	"REG",
	"RSP",
	"FREG",
	"VREG",
	"PAIR",
	"SHIFT",
	"EXTREG",
	"SPR",
	"COND",
	"ZCON",
	"ABCON0",
	"ADDCON0",
	"ABCON",
	"ADDCON",
	"MBCON",
	"MOVCON",
	"BITCON",
	"LCON",
	"VCON",
	"FCON",
	"VCONADDR",
	"AACON",
	"LACON",
	"AECON",
	"SBRA",
	"LBRA",
	"NPAUTO",
	"NSAUTO",
	"PSAUTO",
	"PPAUTO",
	"UAUTO4K_8",
	"UAUTO4K_4",
	"UAUTO4K_2",
	"UAUTO4K",
	"UAUTO8K_8",
	"UAUTO8K_4",
	"UAUTO8K",
	"UAUTO16K_8",
	"UAUTO16K",
	"UAUTO32K",
	"LAUTO",
	"SEXT1",
	"SEXT2",
	"SEXT4",
	"SEXT8",
	"SEXT16",
	"LEXT",
	"ZOREG",
	"NPOREG",
	"NSOREG",
	"PSOREG",
	"PPOREG",
	"UOREG4K_8",
	"UOREG4K_4",
	"UOREG4K_2",
	"UOREG4K",
	"UOREG8K_8",
	"UOREG8K_4",
	"UOREG8K",
	"UOREG16K_8",
	"UOREG16K",
	"UOREG32K",
	"LOREG",
	"ADDR",
	"GOTADDR",
	"TLS_LE",
	"TLS_IE",
	"ROFF",
	"GOK",
	"TEXTSIZE",
	"NCLASS",
}
